# $Id: StrainDAGGenerator.py,v 1.2 2005/11/06 18:36:36 kipp Exp $

#
# Preamble.
#

from glue import segments
from onasys import S5DAGGeneratorA

#
# A DAG generator for the h(t) pipeline.  This DAG generator is a
# modification of S5DAGGeneratorA that uses the list of history files
# recorded by StrainSegGenerator to trim the list of segments before DAG
# construction.
#
# How to use this.  This DAG generator plug-in has a [daggenerator] section
# in the .ini file whose contents are identical to the [daggenerator]
# section used by the S5DAGGeneratorA plug-in.
#

class DAGGeneratorConfig(S5DAGGeneratorA.DAGGeneratorConfig):
	pass

class DAGGeneratorParameters(S5DAGGeneratorA.DAGGeneratorParameters):
	pass

def DAGGeneratorParameterList(clock, config, available, used):
	# chain to S5DAGGeneratorA
	list = S5DAGGeneratorA.DAGGeneratorParameterList(clock, config, available, used)

	# a DAG can be constructed at the start of a segment or where a filter
	# history file is available
	allowed = [s[0] for s in available.get("available", segments.segmentlist())] + [s[0] for s in available.get("filterhistories", segments.segmentlist())]

	# only return DAGGeneratorParameters objects corresponding to allowed
	# starts
	return [params for params in list if params.dataseg[0] in allowed]

class DAGGenerator(S5DAGGeneratorA.DAGGenerator):
	pass
